import dataiku

from dku_utils.core import get_current_project_and_variables, get_project_and_variables
from dku_utils.project.security.sharing import share_object_from_id
from dku_utils.recipes.python_recipe import set_python_recipe_inputs


def import_demand_forecast_data():
    project, variables = get_current_project_and_variables()
    flow = project.get_flow()

    demand_forecast_key = variables["standard"]["demand_forecast_project_key_app"]
    demand_forecast_project, demand_forecast_variables = get_project_and_variables(
        demand_forecast_key
    )
    try:
        demand_forecast_modeling_problem = demand_forecast_variables["standard"][
            "demand_forecast_modeling_problem_app"
        ]
    except KeyError:
        demand_forecast_modeling_problem = "regular"

    demand_forecast_input_zone = list(
        filter(lambda zone: zone.name == "demand_forecast_inputs", flow.list_zones())
    )[0]
    elasticity_zone = list(
        filter(lambda zone: zone.name == "prediction_all_discounts", flow.list_zones())
    )[0]
    same_discount_zone = list(
        filter(lambda zone: zone.name == "prediction_same_discount", flow.list_zones())
    )[0]
    no_discount_zone = list(
        filter(lambda zone: zone.name == "prediction_no_discount", flow.list_zones())
    )[0]

    base_inputs = []

    if "regular" in demand_forecast_modeling_problem:
        demand_model = dataiku.Model(
            "demand_forecast_model", project_key=demand_forecast_key
        )
        share_object_from_id(
            object_id=demand_model.get_id(),
            object_type="SAVED_MODEL",
            current_project=demand_forecast_project,
            target_project_key=project.project_key,
            quick_hare=False,
        )
        demand_model = demand_forecast_project.get_saved_model(demand_model.get_id())
        demand_forecast_input_zone.add_item(demand_model)
        same_discount_zone.add_shared(demand_model)
        elasticity_zone.add_shared(demand_model)
        no_discount_zone.add_shared(demand_model)
        base_inputs.append(f"{demand_forecast_key}.{demand_model.id}")

    if "cold_start" in demand_forecast_modeling_problem:
        demand_model_cold = dataiku.Model(
            "cold_start_demand_forecast_model", project_key=demand_forecast_key
        )
        share_object_from_id(
            object_id=demand_model_cold.get_id(),
            object_type="SAVED_MODEL",
            current_project=demand_forecast_project,
            target_project_key=project.project_key,
            quick_hare=False,
        )
        demand_model_cold = demand_forecast_project.get_saved_model(
            demand_model_cold.get_id()
        )
        demand_forecast_input_zone.add_item(demand_model_cold)
        same_discount_zone.add_shared(demand_model_cold)
        elasticity_zone.add_shared(demand_model_cold)
        no_discount_zone.add_shared(demand_model_cold)

        base_inputs.append(f"{demand_forecast_key}.{demand_model_cold.id}")

    set_python_recipe_inputs(
        project,
        "compute_predicted_demand",
        base_inputs + ["demand_forecast_features_all_discount"],
    )
    set_python_recipe_inputs(
        project,
        "compute_demand_no_discount_predicted",
        base_inputs + ["demand_forecast_features_no_discount"],
    )
    set_python_recipe_inputs(
        project,
        "compute_demand_same_discount_predicted",
        base_inputs + ["demand_forecast_features_same_discount"],
    )
